aboutsummaryrefslogtreecommitdiff
path: root/src/driver/misc-driver.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/driver/misc-driver.cc')
-rw-r--r--src/driver/misc-driver.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/driver/misc-driver.cc b/src/driver/misc-driver.cc
index f8a8228..735d0f9 100644
--- a/src/driver/misc-driver.cc
+++ b/src/driver/misc-driver.cc
@@ -2,7 +2,7 @@
// $Header$
//
// Cactus_gridfn_varindex - get Cactus gridfn variable index
// Cactus_gridfn_data_ptr - get Cactus gridfn data pointer
// ***** template instantiations *****
//
@@ -78,9 +78,9 @@ return varindex;
// pointer is ok)
//
template <typename T>
- T* Cactus_gridfn_data_ptr(const cGH *GH, int varindex,
- const char gridfn_name[],
- bool check_for_NULL /* = true */)
+ T* Cactus_gridfn_dataptr(const cGH *GH, int varindex,
+ const char gridfn_name[],
+ bool check_for_NULL /* = true */)
{
const int time_level = 0;
@@ -89,7 +89,7 @@ T* data_ptr = static_cast<T*>( CCTK_VarDataPtrI(GH, time_level, varindex) );
if (check_for_NULL && (data_ptr == NULL))
then CCTK_VWarn(FATAL_ERROR, __LINE__, __FILE__, CCTK_THORNSTRING,
"\n"
-" Cactus_gridfn_data_ptr(): got unexpected NULL data pointer\n"
+" Cactus_gridfn_dataptr(): got unexpected NULL data pointer\n"
" for Cactus gridfn!\n"
" name=\"%s\" varindex=%d"
,
@@ -100,9 +100,9 @@ return data_ptr;
//******************************************************************************
-template CCTK_REAL* Cactus_gridfn_data_ptr<CCTK_REAL>(const cGH*, int,
- const char*,
- bool /* = true */);
-template CCTK_INT* Cactus_gridfn_data_ptr<CCTK_INT>(const cGH*, int,
- const char*,
- bool /* = true */);
+template CCTK_REAL* Cactus_gridfn_dataptr<CCTK_REAL>(const cGH*, int,
+ const char*,
+ bool /* = true */);
+template CCTK_INT* Cactus_gridfn_dataptr<CCTK_INT>(const cGH*, int,
+ const char*,
+ bool /* = true */);
@@ -2,7 +2,7 @@
//
// Cactus_gridfn_varindex - get Cactus gridfn variable index
-// Cactus_gridfn_data_ptr - get Cactus gridfn data pointer
+// Cactus_gridfn_dataptr - get Cactus gridfn data pointer
// ***** template instantiations *****
//